# Credits

* Matthew Turk <matthewturk@gmail.com>
* Chris Havlin <chris.havlin@gmail.com>
* Chuck Rozhon <rozhon2@illinois.edu>

Additionally, this has been worked on in pieces by many other yt contributors,
which can be found in the main yt repository.
